@@ -3,9 +3,9 @@ package jdk.internal.jshell.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "19.0.1+10" },
-            { "jdk", "19.0.1" },
-            { "release", "19.0.1" },
+            { "full", "24.0.1" },
+            { "jdk", "24.0.1" },
+            { "release", "24.0.1" },
         };
     }
 }
